==> ecs-1.122.0-sources.jar: software/amazon/awscdk/services/ecs/ProxyConfigurations.java <==
package software.amazon.awscdk.services.ecs;

/**
 * The base class for proxy configurations.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.34.0 (build 9b72778)", date = "2021-09-08T20:44:44.530Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ecs.$Module.class, fqn = "@aws-cdk/aws-ecs.ProxyConfigurations")
public class ProxyConfigurations extends software.amazon.jsii.JsiiObject {

    protected ProxyConfigurations(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ProxyConfigurations(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public ProxyConfigurations() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * Constructs a new instance of the ProxyConfiguration class.
     * <p>
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.ProxyConfiguration appMeshProxyConfiguration(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.AppMeshProxyConfigurationConfigProps props) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ecs.ProxyConfigurations.class, "appMeshProxyConfiguration", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ecs.ProxyConfiguration.class), new Object[] { java.util.Objects.requireNonNull(props, "props is required") });
    }
}

==> ecs-1.173.0-sources.jar: software/amazon/awscdk/services/ecs/ProxyConfigurations.java <==
package software.amazon.awscdk.services.ecs;

/**
 * The base class for proxy configurations.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.ecs.*;
 * ProxyConfigurations proxyConfigurations = new ProxyConfigurations();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.67.0 (build 2c027f5)", date = "2022-09-16T18:50:35.909Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ecs.$Module.class, fqn = "@aws-cdk/aws-ecs.ProxyConfigurations")
public class ProxyConfigurations extends software.amazon.jsii.JsiiObject {

    protected ProxyConfigurations(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ProxyConfigurations(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public ProxyConfigurations() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * Constructs a new instance of the ProxyConfiguration class.
     * <p>
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.ProxyConfiguration appMeshProxyConfiguration(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.AppMeshProxyConfigurationConfigProps props) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ecs.ProxyConfigurations.class, "appMeshProxyConfiguration", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ecs.ProxyConfiguration.class), new Object[] { java.util.Objects.requireNonNull(props, "props is required") });
    }
}
